@@ -5,6 +5,6 @@ from __future__ import absolute_import
 from cell2cell.core.cci_scores import (compute_braycurtis_like_cci_score, compute_count_score, compute_jaccard_like_cci_score,
                                        matmul_bray_curtis_like, matmul_count_active, matmul_jaccard_like)
 from cell2cell.core.cell import (Cell, get_cells_from_rnaseq)
-from cell2cell.core.communication_scores import (get_binary_scores, get_continuous_scores)
+from cell2cell.core.communication_scores import (get_binary_scores, get_continuous_scores, compute_ccc_matrix)
 from cell2cell.core.interaction_space import (generate_interaction_elements, InteractionSpace)
 from cell2cell.core.spatial_interactions import (SpatialCCI)
\ No newline at end of file
