@@ -5,4 +5,4 @@ from __future__ import absolute_import
 from cell2cell.datasets.heuristic_data import (HeuristicGOTerms)
 from cell2cell.datasets.random_data import (generate_random_rnaseq, generate_random_ppi, generate_random_cci_scores,
                                             generate_random_metadata)
-from cell2cell.datasets.toy_data import (generate_toy_distance, generate_toy_rnaseq, generate_toy_ppi, genera_toy_metadata)
\ No newline at end of file
+from cell2cell.datasets.toy_data import (generate_toy_distance, generate_toy_rnaseq, generate_toy_ppi, generate_toy_metadata)
\ No newline at end of file
